h1,
h2,
p {
  font-family: 'Helvetica', sans-serif;
  text-align: center;
}

img {
  display: block;
  margin-left: auto;
  margin-right: auto;
}

h1,
h2 {
  font-weight: 900;
}

p {
  font-weight: 300;
}

button {
  -webkit-appearance: none;
  background-color: #1fa3ec;
  border: 0;
  -moz-border-radius: .317rem;
  -webkit-border-radius: .317rem;
  border-radius: .317rem;
  color: #fff;
  cursor: pointer;
  display: inline-block;
  font-size: 1rem;
  -webkit-font-smoothing: antialiased;
  font-weight: 700;
  line-height: 1.5;
  margin: 0;
  padding: .75rem 1rem;
  text-decoration: none;
}

button:hover {
  opacity: .85;
}

button:active {
  -webkit-box-shadow: inset 0 3px 4px hsla(0, 0%, 0%, 0.2);
  -moz-box-shadow: inset 0 3px 4px hsla(0, 0%, 0%, 0.2);
  box-shadow: inset 0 3px 4px hsla(0, 0%, 0%, 0.2);
}

button:focus {
  outline: thin dotted #444;
  outline-offset: -2px;
}

.actual,
.setpoint {
  font-size: 200%;
}

.footer {
  font-size: 12px;
}

.login-body {
  background: #fff;
}

.cell-table {
  display: table;
  height: 100vh;
}

.cell {
  display: table-cell;
  vertical-align: middle;
}

.login-input,
.login-button,
.login-img {
  width: 150px;
}

.login-button {
  margin: 0;
}

.login-img {
  margin-bottom: 25px;
}
